@@ -5,7 +5,7 @@ It's a free(libre) software
 """
 from re import *
 import os,sys
-__version__="1.3.1"
+__version__="1.3.4"
 __author__="<Lone_air_Use@outlook.com>"
 import warnings,traceback
 App=None
@@ -1468,7 +1468,7 @@ def mkgz(f):
 
 def __install__():
     import os
-    os.system("sh install.sh -quiet")
+    os.system("bash install.sh -quiet")
     return
 
 def vercomp(NEW, OLD):
@@ -1513,7 +1513,7 @@ def upgrade():
         except:
             ERR("\033[91mfatal error\033[0m: unable to clone the repository of psml")
             return
-        os.system("sh install.sh -quiet")
+        os.system("bash install.sh -quiet")
         os.chdir("..")
         while 1:
             try:
@@ -1688,7 +1688,7 @@ __install__.__doc__="""Execute the install.sh"""
 __online__.__doc__="""Run a online compile web project server for psml"""
 
 def _start():
-    import sys,os
+    import sys,os,rlcompleter
     w2err=[]
     realargs=[]
     noc=[]
@@ -2052,11 +2052,3 @@ def _start():
                 sys.stderr.write("\033[91mfatal error\033[0m: no such file or directory '%s'\n"%PSMLC)
                 sys.exit()
 
-if __name__=="__main__":
-    try:
-        from rlcompleter import *
-        import readline
-    except:
-        print("\033[95;1mWarning\033[0m: Your python unsupport GNU Readline")
-    _start()
-    exit()
